@@ -19,7 +19,7 @@ with 'Data::Object::Role::Stashable';
 
 use DBI;
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 # ATTRIBUTES
 
@@ -151,7 +151,9 @@ Temporary Mysql Database for Testing
 
   use Test::DB::Mysql;
 
-  my $tdbi = Test::DB::Mysql->new;
+  my $tdbo = Test::DB::Mysql->new;
+
+  # my $dbh = $tdbo->dbh;
 
 =cut
 
@@ -272,7 +274,7 @@ The create method creates a temporary database and returns the invocant.
 
   # given: synopsis
 
-  $tdbi->create;
+  $tdbo->create;
 
   # <Test::DB::Mysql>
 
@@ -292,8 +294,8 @@ The destroy method destroys (drops) the database and returns the invocant.
 
   # given: synopsis
 
-  $tdbi->create;
-  $tdbi->destroy;
+  $tdbo->create;
+  $tdbo->destroy;
 
   # <Test::DB::Mysql>
 
