@@ -11,7 +11,7 @@ use routines;
 use Data::Object::Class;
 use Data::Object::ClassHas;
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 # ATTRIBUTES
 
@@ -22,7 +22,7 @@ has 'database' => (
 );
 
 fun new_database($self) {
-  join '_', 'test_db', time, $$, sprintf "%04d", rand 999
+  join '_', 'testing_db', time, $$, sprintf "%04d", rand 999
 }
 
 # METHODS
