@@ -19,7 +19,7 @@ with 'Data::Object::Role::Stashable';
 
 use DBI;
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 # ATTRIBUTES
 
@@ -174,7 +174,9 @@ Temporary Postgres Database for Testing
 
   use Test::DB::Postgres;
 
-  my $tdbi = Test::DB::Postgres->new;
+  my $tdbo = Test::DB::Postgres->new;
+
+  # my $dbh = $tdbo->dbh;
 
 =cut
 
@@ -295,7 +297,7 @@ The clone method creates a temporary database from a database template.
 
   # given: synopsis
 
-  $tdbi->clone('template0');
+  $tdbo->clone('template0');
 
   # <Test::DB::Postgres>
 
@@ -315,7 +317,7 @@ The create method creates a temporary database and returns the invocant.
 
   # given: synopsis
 
-  $tdbi->create;
+  $tdbo->create;
 
   # <Test::DB::Postgres>
 
@@ -335,8 +337,8 @@ The destroy method destroys (drops) the database and returns the invocant.
 
   # given: synopsis
 
-  $tdbi->create;
-  $tdbi->destroy;
+  $tdbo->create;
+  $tdbo->destroy;
 
   # <Test::DB::Postgres>
 
